@@ -226,7 +226,7 @@ class Item:
 
     def __init__(self, url = None, tag = None, base = None, path = "", cache_path = "", callback = None, \
         page_template = None, print_version_keywords = None, try_use_print_version = True, \
-        allow_scripts = False, as_is = False, content_kwargs = None):
+        allow_scripts = False, as_is = False, content_kwargs = None, reformatter_url = None):
             self.__url = url
             self.__tag = tag
             self.__base = base
@@ -248,6 +248,7 @@ class Item:
             self.title = "untitled"
             self.__as_is = as_is
             self.__content_kwargs = content_kwargs
+            self.__reformatter_url = reformatter_url
 
 
     def __report(self, action, item):
@@ -296,10 +297,16 @@ class Item:
         return (html, base, None)
 
 
+    def get_url_for_reformatter(self, url):
+        if self.__reformatter_url:
+            return self.__reformatter_url % urllib.quote(url)
+        return url
+
+
     def __extract_tag(self):
         self.__report("downloading", self.__url)
-        (html, self.__base, real_url) = get_page_html(self.__url)
-        if not self.__as_is:
+        (html, self.__base, real_url) = get_page_html(self.get_url_for_reformatter(self.__url))
+        if not self.__as_is and not self.__reformatter_url:
             if self.__content_kwargs:
                 self.__tag = html.body.find(**self.__content_kwargs)
             elif self.__try_use_print_version:
@@ -417,7 +424,8 @@ class Feed:
     def __init__(self, url, path = "", cache_path = "", callback = None, title = None, filename = None,
         page_template = None, page_item_template = None, print_version_keywords = None, \
         try_use_print_version = True, delete_before_date = None, allow_scripts = False, \
-        inline_items = False, cache_items = False, include = None, exclude = None, as_is = False, content_kwargs = None):
+        inline_items = False, cache_items = False, include = None, exclude = None, as_is = False,
+        content_kwargs = None, reformatter_url = None):
             self.__url = url
             self.__path = path
             self.__cache_path = cache_path
@@ -444,6 +452,7 @@ class Feed:
                 self.__exclude = re.compile(exclude)
             self.__as_is = as_is
             self.__content_kwargs = content_kwargs
+            self.__reformatter_url = reformatter_url
 
 
     def __report(self, action, item):
@@ -517,7 +526,7 @@ class Feed:
         return Item(url = url, tag = tag, base = base, path = path, cache_path = cache_path, \
             callback = self.__callback, try_use_print_version = self.__try_use_print_version, \
             print_version_keywords = self.__print_version_keywords, allow_scripts = self.__allow_scripts, \
-            as_is = self.__as_is, content_kwargs = self.__content_kwargs)
+            as_is = self.__as_is, content_kwargs = self.__content_kwargs, reformatter_url = self.__reformatter_url)
         
 
     def __add_item(self, div, item):
