@@ -22,7 +22,7 @@ gtk.gdk.threads_init()
 #This is to be able to start Feed Circuit on PC
 try:
     import osso
-    osso_context = osso.Context("org.maemo.feedcircuit", "0.6.3", False)
+    osso_context = osso.Context("org.maemo.feedcircuit", "0.6.4", False)
 except ImportError:
     pass
 
@@ -137,7 +137,7 @@ class FeedConfig:
 
     def __init__(self, url, name, mode, days_to_keep,
         include, exclude, ignore_print_version, icon_filename,
-        message_count, as_is, content_tag, print_version_link, id = None):
+        message_count, as_is, content_tag, print_version_link, reformatter_url, id = None):
         self.id = id
         if not self.id:
             self.id = uuid.uuid1().hex
@@ -153,6 +153,7 @@ class FeedConfig:
         self.as_is = as_is
         self.content_tag = content_tag
         self.print_version_link = print_version_link
+        self.reformatter_url = reformatter_url
         self.icon = None
         self.iter = None
         self.ord_num = 0
@@ -297,6 +298,7 @@ class FeedListModel(gtk.GenericTreeModel):
                 parser.getboolean_default(section, "as is", False),
                 parser.get_default(section, "content tag", ""),
                 parser.get_default(section, "print version link", ""),
+                parser.get_default(section, "reformatter url", ""),
                 section)
             feed_config.ord_num = parser.getint_default(section, "order number", 0)
             self.list.append(feed_config)
@@ -323,6 +325,7 @@ class FeedListModel(gtk.GenericTreeModel):
                 parser.set(feed_config.id, "as is", str(feed_config.as_is))
                 parser.set(feed_config.id, "content tag", feed_config.content_tag)
                 parser.set(feed_config.id, "print version link", feed_config.print_version_link)
+                parser.set(feed_config.id, "reformatter url", feed_config.reformatter_url)
                 parser.set(feed_config.id, "order number", str(i))
                 i += 1
             parser.write(f)
@@ -417,19 +420,23 @@ class ContentWindow(gtk.Dialog):
         self.content_tag_entry = gtk.Entry()
         self.content_tag_entry.set_width_chars(24)
         self.content_tag_entry.connect("changed", self.content_tag_entry_changed)
+        self.reformatter_url_entry = gtk.Entry()
+        self.reformatter_url_entry.connect("changed", self.reformatter_url_entry_changed)
         self.ignore_print_version_button = gtk.CheckButton()
         self.ignore_print_version_button.connect("toggled", self.ignore_print_version_changed)
         self.print_version_link_entry = gtk.Entry()
-        table = gtk.Table(rows = 4, columns = 2)
-        texts = [_("Use as is"), _("Content tag"), _("Ignore print version"), _("Print version link") ]
+        table = gtk.Table(rows = 5, columns = 2)
+        texts = [_("Use as is"), _("Content tag"), _("Reformatting service url"),
+            _("Ignore printable version"), _("Printable version link") ]
         for i in range(0, len(texts)):
             label = gtk.Label(texts[i])
             label.set_alignment(1, 1)
             table.attach(label, 0, 1, i, i + 1, xpadding = 3, ypadding = 3)
         table.attach(self.as_is_button, 1, 2, 0, 1, xpadding = 3, ypadding = 3)
         table.attach(self.content_tag_entry, 1, 2, 1, 2, xpadding = 3, ypadding = 3)
-        table.attach(self.ignore_print_version_button, 1, 2, 2, 3, xpadding = 3, ypadding = 3)
-        table.attach(self.print_version_link_entry, 1, 2, 3, 4, xpadding = 3, ypadding = 3)
+        table.attach(self.reformatter_url_entry, 1, 2, 2, 3, xpadding = 3, ypadding = 3)
+        table.attach(self.ignore_print_version_button, 1, 2, 3, 4, xpadding = 3, ypadding = 3)
+        table.attach(self.print_version_link_entry, 1, 2, 4, 5, xpadding = 3, ypadding = 3)
         self.vbox.add(table)
         self.show_all()
 
@@ -438,6 +445,7 @@ class ContentWindow(gtk.Dialog):
         self.ignore_print_version_button.set_sensitive(not self.as_is_button.get_active())
         self.print_version_link_entry.set_sensitive(not self.as_is_button.get_active())
         self.content_tag_entry.set_sensitive(not self.as_is_button.get_active())
+        self.reformatter_url_entry.set_sensitive(not self.as_is_button.get_active())
 
 
     def ignore_print_version_changed(self, source):
@@ -447,6 +455,13 @@ class ContentWindow(gtk.Dialog):
     def content_tag_entry_changed(self, source):
         self.ignore_print_version_button.set_sensitive(len(self.content_tag_entry.get_text()) == 0)
         self.print_version_link_entry.set_sensitive(len(self.content_tag_entry.get_text()) == 0)
+        self.reformatter_url_entry.set_sensitive(len(self.content_tag_entry.get_text()) == 0)
+
+
+    def reformatter_url_entry_changed(self, source):
+        self.ignore_print_version_button.set_sensitive(len(self.reformatter_url_entry.get_text()) == 0)
+        self.print_version_link_entry.set_sensitive(len(self.reformatter_url_entry.get_text()) == 0)
+        self.content_tag_entry.set_sensitive(len(self.reformatter_url_entry.get_text()) == 0)
 
 
 class EditWindow(gtk.Dialog):
@@ -466,6 +481,7 @@ class EditWindow(gtk.Dialog):
         self.as_is = feed_config.as_is
         self.content_tag = feed_config.content_tag
         self.print_version_link = feed_config.print_version_link
+        self.reformatter_url = feed_config.reformatter_url
         self.url_entry = gtk.Entry()
         self.url_entry.set_width_chars(32)
         self.url_entry.set_text(feed_config.url)
@@ -515,6 +531,7 @@ class EditWindow(gtk.Dialog):
         self.feed_config.ignore_print_version = self.ignore_print_version
         self.feed_config.content_tag = self.content_tag
         self.feed_config.print_version_link = self.print_version_link
+        self.feed_config.reformatter_url = self.reformatter_url
 
 
     def extra_clicked(self, source):
@@ -534,11 +551,13 @@ class EditWindow(gtk.Dialog):
         cnt_window.as_is_button.set_active(self.as_is)
         cnt_window.ignore_print_version_button.set_active(self.ignore_print_version)
         cnt_window.content_tag_entry.set_text(self.content_tag)
+        cnt_window.reformatter_url_entry.set_text(self.reformatter_url)
         cnt_window.print_version_link_entry.set_text(self.print_version_link)
         if cnt_window.run() == gtk.RESPONSE_ACCEPT:
             self.as_is = cnt_window.as_is_button.get_active()
             self.ignore_print_version = cnt_window.ignore_print_version_button.get_active()
             self.content_tag = cnt_window.content_tag_entry.get_text()
+            self.reformatter_url = cnt_window.reformatter_url_entry.get_text()
             self.print_version_link = cnt_window.print_version_link_entry.get_text()
         cnt_window.destroy()
 
@@ -736,7 +755,8 @@ class Program(hildon.Program):
                     cache_items = feed_config.mode == FeedConfig.mode_cache,
                     include = feed_config.include, exclude = feed_config.exclude,
                     as_is = feed_config.as_is, content_kwargs = feed_config.get_content_kwargs(),
-                    print_version_keywords = feed_config.get_print_version_keywords())
+                    print_version_keywords = feed_config.get_print_version_keywords(),
+                    reformatter_url = feed_config.reformatter_url)
                 new_item_count = feed.update()
                 gobject.idle_add(self.feed_updated, feed_config, new_item_count)
         finally:
@@ -794,7 +814,8 @@ class Program(hildon.Program):
                     urllib.urlretrieve(icon_url, os.path.join(create_config_dir(), icon_filename))
             except Exception, ex:
                 pass
-            feed_config =FeedConfig(url, title, FeedConfig.mode_ommit, 7, "", "", False, icon_filename, 0, False, "", "")
+            feed_config =FeedConfig(url, title, FeedConfig.mode_ommit, 7, "", "", False, icon_filename, 0,
+                False, "", "", "")
             edit_window = EditWindow(self.__window, feed_config)
             if edit_window.run() == gtk.RESPONSE_ACCEPT:
                 edit_window.update_feed()
@@ -828,7 +849,7 @@ class Program(hildon.Program):
     def about(self, source):
         dialog = gtk.AboutDialog()
         dialog.set_name("FeedCircuit")
-        dialog.set_version("0.6.3")
+        dialog.set_version("0.6.4")
         dialog.set_website("http://feedcircuit.garage.maemo.org")
         dialog.set_authors([_("George Kibardin")])
         dialog.run()
